@@ -1,14 +1,18 @@
+# SPDX-FileCopyrightText: Copyright (c) 2020 Bryan Siepert for Adafruit Industries
+#
+# SPDX-License-Identifier: MIT
 import board
-import busio
 
 # pylint:disable=no-member,unused-import
-from adafruit_lsm6ds import LSM6DS33, LSM6DSOX, ISM330DHCX, Rate
+from adafruit_lsm6ds import Rate
+from adafruit_lsm6ds.lsm6dsox import LSM6DSOX as LSM6DS
 
-i2c = busio.I2C(board.SCL, board.SDA)
+# from adafruit_lsm6ds.lsm6ds33 import LSM6DS33 as LSM6DS
+# from adafruit_lsm6ds.lsm6dso32 import LSM6DSO32 as LSM6DS
+# from adafruit_lsm6ds.ism330dhcx import ISM330DHCX as LSM6DS
 
-sensor = LSM6DS33(i2c)
-# sensor = LSM6DSOX(i2c)
-# sensor = ISM330DHCX(i2c)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+sensor = LSM6DS(i2c)
 
 while True:
     sensor.accelerometer_data_rate = Rate.RATE_12_5_HZ
